@@ -17,26 +17,24 @@
 # under the License.
 
 """Example DAG demonstrating the usage of the PigOperator."""
+from datetime import datetime
 
 from airflow import DAG
 from airflow.providers.apache.pig.operators.pig import PigOperator
-from airflow.utils.dates import days_ago
-
-args = {
-    'owner': 'airflow',
-}
 
 dag = DAG(
     dag_id='example_pig_operator',
-    default_args=args,
     schedule_interval=None,
-    start_date=days_ago(2),
+    start_date=datetime(2021, 1, 1),
+    catchup=False,
     tags=['example'],
 )
 
+# [START create_pig]
 run_this = PigOperator(
     task_id="run_example_pig_script",
     pig="ls /;",
     pig_opts="-x local",
     dag=dag,
 )
+# [END create_pig]
